
///////////////////////////////////////////////////////////////////////////
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the version 3 of the GNU General Public License //
// as published by the Free Software Foundation.                         //
//                                                                       //
// This program is distributed in the hope that it will be useful, but   //
// WITHOUT ANY WARRANTY; without even the implied warranty of            //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      //
// General Public License for more details.                              //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program. If not, see <http://www.gnu.org/licenses/>.  //
//                                                                       //
// Written by and Copyright (C) Francois Fleuret                         //
// Contact <francois.fleuret@idiap.ch> for comments & bug reports        //
///////////////////////////////////////////////////////////////////////////

#include <iostream>

#include "simple_window.h"

using namespace std;

int main() {
  SimpleWindow window("Mandelbrot", 600, 600);
  int n;
  int depth = 100;

  const int width = window.get_width();
  const int height = window.get_height();

  window.map();

  for(int i = 0; i < width; i++)
    for(int j = 0; j < height; j++) {
      double cr = -2.0 + 3.0 * (double(i)/double(width));
      double ci = -1.5 + 3.0 * (double(j)/double(height));
      double zr = 0, zi = 0;
      for(n = 0; (n < depth) && (zr*zr + zi*zi < 100); n++) {
	double t = zr*zr -zi*zi + cr;
	zi = 2*zr*zi + ci;
	zr = t;
      }

      float a = float(n)/float(depth);

      if(a < 0.5) window.color(0, 0, a*2);
      else        window.color((a-0.5)*2, (a-0.5)*2, 1.0);

      window.draw_point(i, j);
    }

  window.show();

  cout << "Press [ENTER] to close the window.\n";

  cin.get();
}
